TidyOptionId

Enum TidyOptionId 

#[repr(u32)]
pub enum TidyOptionId {
Show 105 variants UnknownOption = 0, AccessibilityCheckLevel = 1, AltText = 2, AnchorAsName = 3, AsciiChars = 4, BlockTags = 5, BodyOnly = 6, BreakBeforeBR = 7, CharEncoding = 8, CoerceEndTags = 9, CSSPrefix = 10, CustomTags = 11, DecorateInferredUL = 12, Doctype = 13, DoctypeMode = 14, DropEmptyElems = 15, DropEmptyParas = 16, DropPropAttrs = 17, DuplicateAttrs = 18, Emacs = 19, EmacsFile = 20, EmptyTags = 21, EncloseBlockText = 22, EncloseBodyText = 23, ErrFile = 24, EscapeCdata = 25, EscapeScripts = 26, FixBackslash = 27, FixComments = 28, FixUri = 29, ForceOutput = 30, GDocClean = 31, HideComments = 32, HtmlOut = 33, InCharEncoding = 34, IndentAttributes = 35, IndentCdata = 36, IndentContent = 37, IndentSpaces = 38, InlineTags = 39, JoinClasses = 40, JoinStyles = 41, KeepFileTimes = 42, KeepTabs = 43, LiteralAttribs = 44, LogicalEmphasis = 45, LowerLiterals = 46, MakeBare = 47, MakeClean = 48, Mark = 49, MergeDivs = 50, MergeEmphasis = 51, MergeSpans = 52, MetaCharset = 53, MuteReports = 54, MuteShow = 55, NCR = 56, Newline = 57, NumEntities = 58, OmitOptionalTags = 59, OutCharEncoding = 60, OutFile = 61, OutputBOM = 62, PPrintTabs = 63, PreserveEntities = 64, PreTags = 65, PriorityAttributes = 66, PunctWrap = 67, Quiet = 68, QuoteAmpersand = 69, QuoteMarks = 70, QuoteNbsp = 71, ReplaceColor = 72, ShowErrors = 73, ShowFilename = 74, ShowInfo = 75, ShowMarkup = 76, ShowMetaChange = 77, ShowWarnings = 78, SkipNested = 79, SortAttributes = 80, StrictTagsAttr = 81, StyleTags = 82, TabSize = 83, UpperCaseAttrs = 84, UpperCaseTags = 85, UseCustomTags = 86, VertSpace = 87, WarnPropAttrs = 88, Word2000 = 89, WrapAsp = 90, WrapAttVals = 91, WrapJste = 92, WrapLen = 93, WrapPhp = 94, WrapScriptlets = 95, WrapSection = 96, WriteBack = 97, XhtmlOut = 98, XmlDecl = 99, XmlOut = 100, XmlPIs = 101, XmlSpace = 102, XmlTags = 103, N_TIDY_OPTIONS = 104,
}
Option IDs are used used to get and/or set configuration option values and retrieve their descriptions.

@remark These enum members all have associated localized strings available which describe the purpose of the option. These descriptions are available via their enum values only.

@sa config.c:option_defs[] for internal implementation details; that array is where you will implement options defined in this enum; and it’s important to add a string describing the option to language_en.h, too.

Variants



UnknownOption = 0

< Unknown option!



AccessibilityCheckLevel = 1

< Accessibility check level



AltText = 2

< Default text for alt attribute



AnchorAsName = 3

< Define anchors as name attributes



AsciiChars = 4

< Convert quotes and dashes to nearest ASCII char



BlockTags = 5

< Declared block tags



BodyOnly = 6

< Output BODY content only



BreakBeforeBR = 7

< Output newline before
or not?



CharEncoding = 8

< In/out character encoding



CoerceEndTags = 9

< Coerce end tags from start tags where probably intended



CSSPrefix = 10

< CSS class naming for clean option



CustomTags = 11

< Internal use ONLY



DecorateInferredUL = 12

< Mark inferred UL elements with no indent CSS



Doctype = 13

< User specified doctype



DoctypeMode = 14

< Internal use ONLY



DropEmptyElems = 15

< Discard empty elements



DropEmptyParas = 16

< Discard empty p elements



DropPropAttrs = 17

< Discard proprietary attributes



DuplicateAttrs = 18

< Keep first or last duplicate attribute



Emacs = 19

< If true, format error output for GNU Emacs



EmacsFile = 20

< Internal use ONLY



EmptyTags = 21

< Declared empty tags



EncloseBlockText = 22

< If yes text in blocks is wrapped in P’s



EncloseBodyText = 23

< If yes text at body is wrapped in P’s



ErrFile = 24

< File name to write errors to



EscapeCdata = 25

< Replace sections with escaped text



EscapeScripts = 26

< Escape items that look like closing tags in script tags



FixBackslash = 27

< Fix URLs by replacing \ with /



FixComments = 28

< Fix comments with adjacent hyphens



FixUri = 29

< Applies URI encoding if necessary



ForceOutput = 30

< Output document even if errors were found



GDocClean = 31

< Clean up HTML exported from Google Docs



HideComments = 32

< Hides all (real) comments in output



HtmlOut = 33

< Output plain HTML, even for XHTML input.



InCharEncoding = 34

< Input character encoding (if different)



IndentAttributes = 35

< Newline+indent before each attribute



IndentCdata = 36

< Indent section



IndentContent = 37

< Indent content of appropriate tags



IndentSpaces = 38

< Indentation n spaces/tabs



InlineTags = 39

< Declared inline tags



JoinClasses = 40

< Join multiple class attributes



JoinStyles = 41

< Join multiple style attributes



KeepFileTimes = 42

< If yes last modied time is preserved



KeepTabs = 43

< If yes keep input source tabs



LiteralAttribs = 44

< If true attributes may use newlines



LogicalEmphasis = 45

< Replace i by em and b by strong



LowerLiterals = 46

< Folds known attribute values to lower case



MakeBare = 47

< Replace smart quotes, em dashes, etc with ASCII



MakeClean = 48

< Replace presentational clutter by style rules



Mark = 49

< Add meta element indicating tidied doc



MergeDivs = 50

< Merge multiple DIVs



MergeEmphasis = 51

< Merge nested B and I elements



MergeSpans = 52

< Merge multiple SPANs



MetaCharset = 53

< Adds/checks/fixes meta charset in the head, based on document type



MuteReports = 54

< Filter these messages from output.



MuteShow = 55

< Show message ID’s in the error table



NCR = 56

< Allow numeric character references



Newline = 57

< Output line ending (default to platform)



NumEntities = 58

< Use numeric entities



OmitOptionalTags = 59

< Suppress optional start tags and end tags



OutCharEncoding = 60

< Output character encoding (if different)



OutFile = 61

< File name to write markup to



OutputBOM = 62

< Output a Byte Order Mark (BOM) for UTF-16 encodings



PPrintTabs = 63

< Indent using tabs istead of spaces



PreserveEntities = 64

< Preserve entities



PreTags = 65

< Declared pre tags



PriorityAttributes = 66

< Attributes to place first in an element



PunctWrap = 67

< consider punctuation and breaking spaces for wrapping



Quiet = 68

< No ‘Parsing X’, guessed DTD or summary



QuoteAmpersand = 69

< Output naked ampersand as &



QuoteMarks = 70

< Output “ marks as "



QuoteNbsp = 71

< Output non-breaking space as entity



ReplaceColor = 72

< Replace hex color attribute values with names



ShowErrors = 73

< Number of errors to put out



ShowFilename = 74

< If true, the input filename is displayed with the error messages



ShowInfo = 75

< If true, info-level messages are shown



ShowMarkup = 76

< If false, normal output is suppressed



ShowMetaChange = 77

< show when meta http-equiv content charset was changed - compatibility



ShowWarnings = 78

< However errors are always shown



SkipNested = 79

< Skip nested tags in script and style CDATA



SortAttributes = 80

< Sort attributes



StrictTagsAttr = 81

< Ensure tags and attributes match output HTML version



StyleTags = 82

< Move sytle to head



TabSize = 83

< Expand tabs to n spaces



UpperCaseAttrs = 84

< Output attributes in upper not lower case



UpperCaseTags = 85

< Output tags in upper not lower case



UseCustomTags = 86

< Enable Tidy to use autonomous custom tags



VertSpace = 87

< degree to which markup is spread out vertically



WarnPropAttrs = 88

< Warns on proprietary attributes



Word2000 = 89

< Draconian cleaning for Word2000



WrapAsp = 90

< Wrap within ASP pseudo elements



WrapAttVals = 91

< Wrap within attribute values



WrapJste = 92

< Wrap within JSTE pseudo elements



WrapLen = 93

< Wrap margin



WrapPhp = 94

< Wrap consecutive PHP pseudo elements



WrapScriptlets = 95

< Wrap within JavaScript string literals



WrapSection = 96

< Wrap within <![ … ]> section tags



WriteBack = 97

< If true then output tidied markup



XhtmlOut = 98

< Output extensible HTML



XmlDecl = 99

< Add for XML docs



XmlOut = 100

< Create output as XML



XmlPIs = 101

< If set to yes PIs must end with ?>



XmlSpace = 102

< If set to yes adds xml:space attr as needed



XmlTags = 103

< Treat input as XML



N_TIDY_OPTIONS = 104

< Must be last