pub unsafe extern "C" fn getStringKeyList() -> TidyIteratorExpand description
Initiates an iterator for a list of string key codes available in Tidy. This iterator allows you to iterate through all of the codes. In order to iterate through the codes, initiate the iterator with this function, and then use getNextStringKey() to retrieve the first and subsequent codes. For example: @code{.c} TidyIterator itKey = getErrorCodeList(); while ( itKey ) { uint code = getNextStringKey( &itKey ); // do something with the code, such as lookup a string. } @endcode @remark These are provided for documentation generation purposes, and probably aren’t of much use to the average LibTidy implementor. @result Returns a TidyIterator, which is a token used to represent the current position in a list within LibTidy.