getWindowsLanguageList

Function getWindowsLanguageList 

pub unsafe extern "C" fn getWindowsLanguageList() -> TidyIterator
Initiates an iterator for a list of Tidy’s Windows<->POSIX locale mappings. This iterator allows you to iterate through this list. In order to iterate through the list, initiate the iterator with this function, and then use getNextWindowsLanguage() to retrieve the first and subsequent codes. For example: @code{.c} TidyIterator itList = getWindowsLanguageList(); while ( itList ) { tidyLocaleMapItem *item = getNextWindowsLanguage( &itList ); // do something such as get the TidyLangWindowsName(item). } @endcode @result Returns a TidyIterator, which is a token used to represent the current position in a list within LibTidy.