tidyFileExists

Function tidyFileExists 

pub unsafe extern "C" fn tidyFileExists(
    tdoc: TidyDoc,
    filename: ctmbstr,
) -> Bool
Determine whether or not a particular file exists. On Unix systems, the use of the tilde to represent the user’s home directory is supported. @result Returns yes or no, indicating whether or not the file exists.