pub unsafe extern "C" fn tidyGetArgFormat(
tmessage: TidyMessage,
arg: *mut TidyMessageArgument,
) -> ctmbstrExpand description
Returns the format specifier of the given message argument. The memory for this string is cleared upon termination of the callback, so do be sure to make your own copy. @result Returns the format specifier string of the given argument.