pub unsafe extern "C" fn tidyGetArgValueUInt(
tmessage: TidyMessage,
arg: *mut TidyMessageArgument,
) -> uintExpand description
Returns the unsigned integer value of the given message argument. An assertion will be generated if the argument type is not an unsigned int. @result Returns the unsigned integer value of the given argument.