pub unsafe extern "C" fn tidyGetEmacsFile(tdoc: TidyDoc) -> ctmbstrExpand description
Get the file path to use for reports when TidyEmacs is being used. This
function provides a proper interface for using the hidden, internal-only
TidyEmacsFile configuration option.
@param tdoc The tidy document for which you want to fetch the file path.
@result Returns a string indicating the file path.