pub unsafe extern "C" fn tidyGetMessageColumn(
tmessage: TidyMessage,
) -> c_intExpand description
Get the column the message applies to. @param tmessage Specify the message that you are querying. @result Returns the column number, if any, that generated the message.