tidyGetMessageIsMuted

Function tidyGetMessageIsMuted 

pub unsafe extern "C" fn tidyGetMessageIsMuted(
    tmessage: TidyMessage,
) -> Bool
Get the muted status of the message, that is, whether or not the current configuration indicated that this message should be muted. @param tmessage Specify the message that you are querying. @result Returns a Bool indicating that the config indicates muting this message.