pub unsafe extern "C" fn tidyGetMessagePrefixDefault(
tmessage: TidyMessage,
) -> ctmbstrExpand description
Get the prefix part of a message in the default language. @param tmessage Specify the message that you are querying. @result Returns the message prefix part of a string as Tidy would display it in the console application.