tidyOptGetDeclTagList

Function tidyOptGetDeclTagList 

pub unsafe extern "C" fn tidyOptGetDeclTagList(
    tdoc: TidyDoc,
) -> TidyIterator
Initiates an iterator for a list of user-declared tags, including autonomous custom tags detected in the document if @ref TidyUseCustomTags is not set to no. This iterator allows you to iterate through all of the custom tags. In order to iterate through the tags, initiate the iterator with this function, and then use tidyOptGetNextDeclTag() to retrieve the first and subsequent tags. For example: @code{.c} TidyIterator itTag = tidyOptGetDeclTagList( tdoc ); while ( itTag ) { printf(ā€œ%sā€, tidyOptGetNextDeclTag( tdoc, TidyBlockTags, &itTag )); } @endcode @param tdoc An instance of a TidyDoc to query. @result Returns a TidyIterator, which is a token used to represent the current position in a list within LibTidy.