pub unsafe extern "C" fn tidyOptGetDefault(opt: TidyOption) -> ctmbstrExpand description
Get default value of given Option as a string @param opt An instance of a TidyOption to query. @result A string indicating the default value of the specified option.