tidyOptGetDefaultBool

Function tidyOptGetDefaultBool 

pub unsafe extern "C" fn tidyOptGetDefaultBool(
    opt: TidyOption,
) -> Bool
Get default value of given Option as a Boolean value @param opt An instance of a TidyOption to query. @result A boolean indicating the default value of the specified option.