pub unsafe extern "C" fn tidyOptGetDefaultInt(
opt: TidyOption,
) -> ulongExpand description
Get default value of given Option as an unsigned integer @param opt An instance of a TidyOption to query. @result An unsigned integer indicating the default value of the specified option.