pub unsafe extern "C" fn tidyOptGetDoc(
tdoc: TidyDoc,
opt: TidyOption,
) -> ctmbstrExpand description
Get the description of the specified option. @result Returns a string containing a description of the given option.
pub unsafe extern "C" fn tidyOptGetDoc(
tdoc: TidyDoc,
opt: TidyOption,
) -> ctmbstrGet the description of the specified option. @result Returns a string containing a description of the given option.