pub unsafe extern "C" fn tidyOptGetInt(
tdoc: TidyDoc,
optId: TidyOptionId,
) -> ulongExpand description
Get current option value as an integer. @result Returns the integer value of the specified option.
pub unsafe extern "C" fn tidyOptGetInt(
tdoc: TidyDoc,
optId: TidyOptionId,
) -> ulongGet current option value as an integer. @result Returns the integer value of the specified option.