pub unsafe extern "C" fn tidyOptGetMutedMessageList(
tdoc: TidyDoc,
) -> TidyIteratorExpand description
Initiates an iterator for a list of muted messages. This iterator allows
you to iterate through all of the priority attributes defined with the
mute configuration option. In order to iterate through the list, initiate
with this function, and then use tidyOptGetNextMutedMessage() to retrieve
the first and subsequent attributes.
For example:
@code{.c}
TidyIterator itAttr = tidyOptGetMutedMessageList( tdoc );
while ( itAttr ) {
printf(ā%sā, tidyOptGetNextMutedMessage( tdoc, &itAttr ));
}
@endcode
@param tdoc An instance of a TidyDoc to query.
@result Returns a TidyIterator, which is a token used to represent the
current position in a list within LibTidy.