tidyOptGetNextDeclTag

Function tidyOptGetNextDeclTag 

pub unsafe extern "C" fn tidyOptGetNextDeclTag(
    tdoc: TidyDoc,
    optId: TidyOptionId,
    iter: *mut TidyIterator,
) -> ctmbstr
Given a valid TidyIterator initiated with tidyOptGetDeclTagList(), returns a string representing a user-declared or autonomous custom tag. @remark Specifying optId limits the scope of the tags to one of @ref TidyInlineTags, @ref TidyBlockTags, @ref TidyEmptyTags, or @ref TidyPreTags. Note that autonomous custom tags (if used) are added to one of these option types, depending on the value of @ref TidyUseCustomTags. @result A string containing the next tag.