tidyOptIsReadOnly

Function tidyOptIsReadOnly 

pub unsafe extern "C" fn tidyOptIsReadOnly(opt: TidyOption) -> Bool
Is Option read-only? Some options (mainly internal use only options) are read-only. @deprecated This is no longer a valid test for the public API; instead you should test an option’s availability using tidyOptGetCategory() against TidyInternalCategory. This API will be removed! @param opt An instance of a TidyOption to query. @result Returns yes or no depending on whether or not the specified option is read-only.