tidySetConfigChangeCallback

Function tidySetConfigChangeCallback 

pub unsafe extern "C" fn tidySetConfigChangeCallback(
    tdoc: TidyDoc,
    pCallback: TidyConfigChangeCallback,
) -> Bool
Applications using TidyLib may want to be informed when changes to options are made. Temporary changes made internally by Tidy are not reported, but permanent changes made by Tidy (such as indent-spaces or output-encoding) will be reported. @note This callback is not currently implemented. @result Returns yes upon success.