pub unsafe extern "C" fn tidySetEmacsFile(
tdoc: TidyDoc,
filePath: ctmbstr,
)Expand description
Set the file path to use for reports when TidyEmacs is being used. This
function provides a proper interface for using the hidden, internal-only
TidyEmacsFile configuration option.