pub unsafe extern "C" fn tidySetPrettyPrinterCallback(
tdoc: TidyDoc,
callback: TidyPPProgress,
) -> BoolExpand description
This function informs Tidy to use the specified callback for tracking the pretty-printing process progress.
pub unsafe extern "C" fn tidySetPrettyPrinterCallback(
tdoc: TidyDoc,
callback: TidyPPProgress,
) -> BoolThis function informs Tidy to use the specified callback for tracking the pretty-printing process progress.