pub unsafe extern "C" fn tidySetReportFilter(
tdoc: TidyDoc,
filtCallback: TidyReportFilter,
) -> BoolExpand description
This function informs Tidy to use the specified callback to send reports.
pub unsafe extern "C" fn tidySetReportFilter(
tdoc: TidyDoc,
filtCallback: TidyReportFilter,
) -> BoolThis function informs Tidy to use the specified callback to send reports.