TidyConfigChangeCallback

Type Alias TidyConfigChangeCallback 

pub type TidyConfigChangeCallback = Option<unsafe extern "C" fn(tdoc: TidyDoc, option: TidyOption)>;
This typedef represents the required signature for your provided callback function should you wish to register one with tidySetConfigChangeCallback(). Your callback function will be provided with the following parameters. @param tdoc The document instance for which the callback was invoked. @param option The option that will be changed.

Aliased Type

pub enum TidyConfigChangeCallback {
    None,
    Some(unsafe extern "C" fn(*const _TidyDoc, *const _TidyOption)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const _TidyDoc, *const _TidyOption))

Some value of type T.