TidyOptCallback

Type Alias TidyOptCallback 

pub type TidyOptCallback = Option<unsafe extern "C" fn(option: ctmbstr, value: ctmbstr) -> Bool>;
This typedef represents the required signature for your provided callback function should you wish to register one with tidySetOptionCallback(). Your callback function will be provided with the following parameters. Note that this is deprecated and you should instead migrate to tidySetConfigCallback(). @param option The option name that was provided. @param value The option value that was provided @return Your callback function will return yes if it handles the provided option, or no if it does not. In the latter case, Tidy will issue an unknown configuration option error.

Aliased Type

pub enum TidyOptCallback {
    None,
    Some(unsafe extern "C" fn(*const i8, *const i8) -> u32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const i8, *const i8) -> u32)

Some value of type T.