pub unsafe extern "C" fn tidyGetMessagePos(
tmessage: TidyMessage,
) -> ctmbstrExpand description
Get the position part part of the message in the current language. @param tmessage Specify the message that you are querying. @result Returns the positional part of a string as Tidy would display it in the console application.