pub unsafe extern "C" fn tidyNodeIsProp( tdoc: TidyDoc, tnod: TidyNode, ) -> Bool
Indicates whether or not the node is a propriety type. @result Returns a bool indicating whether or not the node is a proprietary type.