pub unsafe extern "C" fn tidyOptGetDefaultBool(
opt: TidyOption,
) -> BoolExpand description
Get default value of given Option as a Boolean value @param opt An instance of a TidyOption to query. @result A boolean indicating the default value of the specified option.