pub unsafe extern "C" fn tidySetOptionCallback(
tdoc: TidyDoc,
pOptCallback: TidyOptCallback,
) -> BoolExpand description
Applications using TidyLib may want to augment command-line and
configuration file options. Setting this callback allows a LibTidy
application developer to examine command-line and configuration file options
after LibTidy has examined them and failed to recognize them.
Note that this is deprecated and you should instead migrate to
tidySetConfigCallback().
@result Returns yes upon success.