pub type TidyMessageCallback = Option<unsafe extern "C" fn(tmessage: TidyMessage) -> Bool>;Expand description
This typedef represents the required signature for your provided callback
function should you wish to register one with tidySetMessageCallback().
Your callback function will be provided with the following parameters.
@param tmessage An opaque type used as a token against which other API
calls can be made.
@return Your callback function will return yes if Tidy should include the
report in its own output sink, or no if Tidy should suppress it.
Aliased Type
pub enum TidyMessageCallback {
None,
Some(unsafe extern "C" fn(*const _TidyMessage) -> u32),
}